@@ -758,16 +758,24 @@ void DocAccessible::AttributeChanged(dom::Element* aElement,
     return;
   }
 
-  // Ignore attribute change if the element doesn't have an accessible (at all
-  // or still) if the element is not a root content of this document accessible
-  // (which is treated as attribute change on this document accessible).
-  // Note: we don't bail if all the content hasn't finished loading because
-  // these attributes are changing for a loaded part of the content.
   LocalAccessible* accessible = GetAccessible(aElement);
   if (!accessible) {
-    if (mContent != aElement) return;
-
-    accessible = this;
+    if (mContent == aElement) {
+      // The attribute change occurred on the root content of this
+      // DocAccessible, so handle it as an attribute change on this.
+      accessible = this;
+    } else {
+      if (aModType == dom::MutationEvent_Binding::ADDITION &&
+          aria::AttrCharacteristicsFor(aAttribute) & ATTR_GLOBAL) {
+        // The element doesn't have an Accessible, but a global ARIA attribute
+        // was just added, which means we should probably create an Accessible.
+        ContentInserted(aElement, aElement->GetNextSibling());
+        return;
+      }
+      // The element doesn't have an Accessible, so ignore the attribute
+      // change.
+      return;
+    }
   }
 
   MOZ_ASSERT(accessible->IsBoundToParent() || accessible->IsDoc(),
