@@ -180,9 +180,20 @@ const MENU_BUTTON = "menubutton";
  * Collection of timeouts that are used to ensure something should not happen.
  */
 const TIMEOUT_ENSURE_PROFILE_NOT_SAVED = 1000;
-const TIMEOUT_ENSURE_CC_EDIT_DIALOG_NOT_CLOSED = 500;
+const TIMEOUT_ENSURE_CC_DIALOG_NOT_CLOSED = 500;
 const TIMEOUT_ENSURE_AUTOCOMPLETE_NOT_SHOWN = 1000;
 
+async function ensureCreditCardDialogNotClosed(win) {
+  const unloadHandler = () => {
+    ok(false, "Credit card dialog shouldn't be closed");
+  };
+  win.addEventListener("unload", unloadHandler);
+  await new Promise(resolve =>
+    setTimeout(resolve, TIMEOUT_ENSURE_CC_DIALOG_NOT_CLOSED)
+  );
+  win.removeEventListener("unload", unloadHandler);
+}
+
 function getDisplayedPopupItems(
   browser,
   selector = ".autocomplete-richlistitem"
@@ -340,7 +351,7 @@ async function focusUpdateSubmitForm(target, args, submit = true) {
 
     for (const [selector, value] of Object.entries(obj.newValues)) {
       element = form.querySelector(selector);
-      if (element instanceof content.HTMLInputElement) {
+      if (content.HTMLInputElement.isInstance(element)) {
         element.setUserInput(value);
       } else {
         element.value = value;
@@ -420,7 +431,7 @@ async function focusAndWaitForFieldsIdentified(browserOrContext, selector) {
 
   // If a browsing context was supplied, focus its parent frame as well.
   if (
-    browserOrContext instanceof BrowsingContext &&
+    BrowsingContext.isInstance(browserOrContext) &&
     browserOrContext.parent != browserOrContext
   ) {
     await SpecialPowers.spawn(
@@ -623,6 +634,14 @@ function getAddresses() {
   return getRecords({ collectionName: "addresses" });
 }
 
+async function ensureNoAddressSaved() {
+  await new Promise(resolve =>
+    setTimeout(resolve, TIMEOUT_ENSURE_PROFILE_NOT_SAVED)
+  );
+  const addresses = await getAddresses();
+  is(addresses.length, 0, "No address was saved");
+}
+
 function getCreditCards() {
   return getRecords({ collectionName: "creditCards" });
 }
